/*!
 * @file        main.c
 *
 * @brief       Main program body
 *
 * @version     V1.0.3
 *
 * @date        2023-07-31
 *
 * @attention
 *
 *  Copyright (C) 2021-2023 Geehy Semiconductor
 *
 *  You may not use this file except in compliance with the
 *  GEEHY COPYRIGHT NOTICE (GEEHY SOFTWARE PACKAGE LICENSE).
 *
 *  The program is only for reference, which is distributed in the hope
 *  that it will be useful and instructional for customers to develop
 *  their software. Unless required by applicable law or agreed to in
 *  writing, the program is distributed on an "AS IS" BASIS, WITHOUT
 *  ANY WARRANTY OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the GEEHY SOFTWARE PACKAGE LICENSE for the governing permissions
 *  and limitations under the License.
 */

/* Includes */
#include "main.h"
#include "Board.h"

/** @addtogroup Examples
  @{
  */

/** @addtogroup GPIO_Toggle
  @{
  */

/** @defgroup GPIO_Toggle_Macros Macros
  @{
  */
#ifdef APM32F411
#define APM_LEDInit    APM_TINY_LEDInit
#define APM_LEDToggle  APM_TINY_LEDToggle
#else
#define APM_LEDInit    APM_MINI_LEDInit
#define APM_LEDToggle  APM_MINI_LEDToggle
#endif

/**@} end of group GPIO_Toggle_Macros */

/** @defgroup GPIO_Toggle_Functions Functions
  @{
  */

/*!
 * @brief     Main program
 *
 * @param     None
 *
 * @retval    None
 */
int main(void)
{
    APM_LEDInit(LED2);
    APM_LEDInit(LED3);
    /* Init delay function */
    Delay_Init();

    while (1)
    {
        Delay_ms(500);
        APM_LEDToggle(LED2);
        APM_LEDToggle(LED3);
    }
}

/**@} end of group GPIO_Toggle_Functions */
/**@} end of group GPIO_Toggle */
/**@} end of group Examples */
