/*!
 * @file       main.c
 *
 * @brief      Main program body
 *
 * @version     V1.0.3
 *
 * @date        2023-07-31
 *
 * @attention
 *
 *  Copyright (C) 2021-2023 Geehy Semiconductor
 *
 *  You may not use this file except in compliance with the
 *  GEEHY COPYRIGHT NOTICE (GEEHY SOFTWARE PACKAGE LICENSE).
 *
 *  The program is only for reference, which is distributed in the hope
 *  that it will be useful and instructional for customers to develop
 *  their software. Unless required by applicable law or agreed to in
 *  writing, the program is distributed on an "AS IS" BASIS, WITHOUT
 *  ANY WARRANTY OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the GEEHY SOFTWARE PACKAGE LICENSE for the governing permissions
 *  and limitations under the License.
 */

/* Includes */
#include "main.h"
#include "Board.h"
#include "rtthread.h"

/** @addtogroup Examples
  @{
  */

/** @addtogroup RT-thread
  @{
  */

/** @defgroup RT-thread_Macros Macros
  @{
  */

#ifdef APM32F411
#define APM_LEDToggle  APM_TINY_LEDToggle
#define APM_LEDInit    APM_TINY_LEDInit
#else
#define APM_LEDToggle  APM_MINI_LEDToggle
#define APM_LEDInit    APM_MINI_LEDInit
#endif /* APM32F411 */

/**@} end of group RT-thread_Macros */

/** @defgroup RT-thread_Functions Functions
  @{
  */

static rt_thread_t led1_thread = RT_NULL;
static void led1_thread_entry(void* parameter);

static void led1_thread_entry(void* parameter)
{
    while (1)
    {
        APM_LEDToggle(LED3);
        rt_thread_delay(1000);
        APM_LEDToggle(LED2);
    }
}

/*!
 * @brief       Main program
 *
 * @param       None
 *
 * @retval      None
 *
 */
int main(void)
{
    APM_LEDInit(LED2);
    APM_LEDInit(LED3);

    led1_thread = rt_thread_create("led1",
                                   led1_thread_entry,
                                   RT_NULL,
                                   512,
                                   3,
                                   20);
    rt_thread_startup(led1_thread);
}

/**@} end of group RT-thread_Functions */
/**@} end of group RT-thread */
/**@} end of group Examples */
